use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( examples lib script t xt ) );
__DATA__
AfterBuild
AfterMint
AfterRelease
Al
BeforeArchive
BeforeBuild
BeforeRelease
Clean
David
Dist
Etheridge
Golden
Karen
Mengué
Miyagawa
Newkirk
Nickolay
Olivier
Platonov
Plugin
Randy
Raudssus
Release
Role
Run
Runner
Sibley
Social
Software
Stauner
Tatsuhiko
Test
Thomas
Torsten
Zilla
dagolden
dolmen
ether
github
https
irc
lib
miyagawa
nplatonov
rwstauner
torsten
tsibley
